@@ -3,8 +3,8 @@ import unittest
 
 import requests_mock
 
-import abodepy
-import abodepy.helpers.constants as CONST
+import jaraco.abode
+import jaraco.abode.helpers.constants as CONST
 
 import tests.mock.login as LOGIN
 import tests.mock.oauth_claims as OAUTH_CLAIMS
@@ -24,7 +24,7 @@ class TestDimmer(unittest.TestCase):
 
     def setUp(self):
         """Set up Abode module."""
-        self.abode = abodepy.Abode(
+        self.abode = jaraco.abode.Abode(
             username=USERNAME, password=PASSWORD, disable_cache=True
         )
 
@@ -158,5 +158,5 @@ class TestDimmer(unittest.TestCase):
             ),
         )
 
-        with pytest.raises(abodepy.AbodeException):
+        with pytest.raises(jaraco.abode.AbodeException):
             device.switch_on()
